pub fn parse_str_with_file(
source: &str,
file: Option<&str>,
) -> Result<ParseOutput, ParseError>Expand description
Parse with a file label that gets attached to every SpecLocation.
pub fn parse_str_with_file(
source: &str,
file: Option<&str>,
) -> Result<ParseOutput, ParseError>Parse with a file label that gets attached to every SpecLocation.